@@ -1,29 +1,3 @@
-/*
-#*****************************************************************************
-#*                                                                           *
-#*                          Gellyfish Software                               *
-#*                                                                           *
-#*                                                                           *
-#*****************************************************************************
-#*                                                                           *
-#*      PROGRAM     :  Linux::Svgalib                                        *
-#*                                                                           *
-#*      AUTHOR      :  JNS                                                   *
-#*                                                                           *
-#*      DESCRIPTION :  Object Oriented perl Interface to svgalib             *
-#*                                                                           *
-#*                                                                           *
-#*****************************************************************************
-#*                                                                           *
-#*      $Log: constants.c,v $
-#*      Revision 1.1  2001/04/09 06:18:26  gellyfish
-#*      Initial revision
-#*
-#*                                                                           *
-#*                                                                           *
-#*****************************************************************************
-*/
-
 #include "EXTERN.h"
 #include "perl.h"
 #include "XSUB.h"
@@ -34,13 +8,6 @@
 /*  This stuff is just so ugly I had to put it in a separate file */
 
   
-static int
-not_here(char *s)
-{
-    croak("%s not implemented on this architecture", s);
-    return -1;
-}
-
 static double
 constant_ACCELFLAG_PO(char *name, int len, int arg)
 {
@@ -4292,7 +4259,7 @@ constant_VGA_(char *name, int len, int arg)
     case 'H':
 	if (strEQ(name + 4, "H")) {	/* VGA_ removed */
 #ifdef VGA_H
-	    return VGA_H;
+	    return 1;
 #else
 	    goto not_there;
 #endif
